(function (Drupal, once) {
    'use strict';
  
    /**
     * Dynamic read time calculation for content editing.
     */
    Drupal.behaviors.readTimeCalculator = {
      attach: function (context, settings) {
        // Select text areas for read time calculation
        const textareas = context.querySelectorAll('.field--type-text-with-summary textarea, .field--type-text-long textarea');
        
        once('read-time-calculator', textareas).forEach(function(textarea) {
          const wrapper = textarea.closest('.form-item');
          
          // Create read time display element
          const readTimeDisplay = document.createElement('div');
          readTimeDisplay.className = 'read-time-live';
          readTimeDisplay.style.marginTop = '5px';
          readTimeDisplay.style.fontSize = '0.9em';
          readTimeDisplay.style.color = '#666';
          readTimeDisplay.style.fontStyle = 'italic';
          
          // Append to wrapper
          wrapper.appendChild(readTimeDisplay);
          
          // Calculate and update read time
          function updateReadTime() {
            const text = textarea.value;
            const words = text.trim().split(/\s+/).filter(word => word.length > 0);
            const wordCount = text.trim() === '' ? 0 : words.length;
            const minutes = Math.ceil(wordCount / 200); // Use default 200 WPM
            
            if (wordCount > 0) {
              readTimeDisplay.innerHTML = Drupal.t('📖 Estimated read time: @minutes min (@words words)', {
                '@minutes': minutes,
                '@words': wordCount
              });
            } else {
              readTimeDisplay.innerHTML = Drupal.t('📖 Start typing to see read time estimate');
            }
          }
          
          // Debounce function to avoid excessive calculations
          let timeoutId;
          function debouncedUpdate() {
            clearTimeout(timeoutId);
            timeoutId = setTimeout(updateReadTime, 300);
          }
          
          // Event listeners
          textarea.addEventListener('input', debouncedUpdate);
          textarea.addEventListener('paste', function() {
            // Small delay for paste to complete
            setTimeout(updateReadTime, 10);
          });
          
          // Initial calculation
          updateReadTime();
        });
      }
    };
  
  })(Drupal, once);